@@ -3,7 +3,9 @@ package Spreadsheet::Engine::Function::RATE;
 use strict;
 use warnings;
 
-use base 'Spreadsheet::Engine::Function::investment';
+use base 'Spreadsheet::Engine::Fn::investment';
+
+use Spreadsheet::Engine::Fn::Approximator 'iterate';
 
 sub argument_count { -3 => 6 }
 sub signature { 'n', 'n', 'n', 'n', 'n', 'n' }
@@ -13,38 +15,17 @@ sub calculate {
   my ($self, $n, $payment, $pv, $fv, $paytype, $guess) = @_;
   $fv ||= 0;
   $paytype = $paytype ? 1 : 0;
-  $guess ||= 0.1;
-
-  # rate is calculated by repeated approximations
-  # The deltas are used to calculate new guesses
-
-  my $olddelta;
-  my $maxloop = 100;
-  my $tries   = 0;
-  my $delta   = 1;
-  my $epsilon = 0.0000001;               # this is close enough
-  my $rate    = $guess || 0.00000001;    # zero is not allowed
-  my $oldrate = 0;
-
-  while (($delta >= 0 ? $delta : -$delta) > $epsilon && ($rate != $oldrate)) {
-    $delta = $fv + $pv * (1 + $rate)**$n + $payment * (1 + $rate * $paytype) *
-      ((1 + $rate)**$n - 1) / $rate;
-    if (defined $olddelta) {
-      my $m = ($delta - $olddelta) / ($rate - $oldrate)
-        || .001;                         # get slope (not zero)
-      $oldrate  = $rate;
-      $rate     = $rate - $delta / $m;    # look for zero crossing
-      $olddelta = $delta;
-    } else {                              # first time - no old values
-      $oldrate  = $rate;
-      $rate     = 1.1 * $rate;
-      $olddelta = $delta;
-    }
-
-    # Barf if we don't converge
-    die Spreadsheet::Engine::Error->num if ++$tries >= $maxloop;
-  }
 
+  my $rate = iterate(
+    max_iterations => 100,
+    initial_guess  => $guess || 0.1,
+    function       => sub {
+      my $rate = shift;
+      return $fv + $pv * (1 + $rate)**$n + $payment * (1 + $rate * $paytype) *
+        ((1 + $rate)**$n - 1) / $rate;
+    },
+  );
+  die Spreadsheet::Engine::Error->num unless defined $rate;
   return $rate;
 }
 
